// $Id$
/**
* Copyright (C) 2014 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.molecular.editor;


import java.util.Arrays;
import java.util.List;
import java.util.UUID;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IPersistableElement;

import eu.etaxonomy.cdm.api.service.molecular.ISequenceService;
import eu.etaxonomy.cdm.model.molecular.Sequence;
import eu.etaxonomy.taxeditor.editor.CdmEntitySessionInput;
import eu.etaxonomy.taxeditor.store.CdmStore;



/**
 * @author pplitzner
 * @author Ben Stöver
 * @date 04.08.2014
 */
public class AlignmentEditorInput extends CdmEntitySessionInput implements IEditorInput {
    private static final String name = "AlignmentEditor";


    private final UUID sequenceNodeUuid;
    private Sequence sequenceNode;

    public AlignmentEditorInput(UUID sequenceNodeUuid) {
        super(false);
		this.sequenceNodeUuid = sequenceNodeUuid;
		initSession();
	}


	/* (non-Javadoc)
     * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
     */
    @Override
    public Object getAdapter(Class adapter) {
        // TODO Auto-generated method stub
        return null;
    }


    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#exists()
     */
    @Override
    public boolean exists() {
        // TODO Auto-generated method stub
        return false;
    }


    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getImageDescriptor()
     */
    @Override
    public ImageDescriptor getImageDescriptor() {
        // TODO Auto-generated method stub
        return null;
    }


    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getName()
     */
    @Override
    public String getName() {
        return name;
    }


    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getPersistable()
     */
    @Override
    public IPersistableElement getPersistable() {
        return null;
    }


    /* (non-Javadoc)
     * @see org.eclipse.ui.IEditorInput#getToolTipText()
     */
    @Override
    public String getToolTipText() {
        return name;
    }


	/**
	 * Returns the {@link UUID} of the sequence CDM node that should be edited by the {@link AlignmentEditor} this object
	 * is used with.
	 *
	 * @return the uuid of the CDM node to work on
	 */
	public UUID getSequenceNodeUuid() {
		return sequenceNodeUuid;
	}


	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((sequenceNodeUuid == null) ? 0 : sequenceNodeUuid.hashCode());
		return result;
	}


	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
            return true;
        }
		if (obj == null) {
            return false;
        }
		if (getClass() != obj.getClass()) {
            return false;
        }
		AlignmentEditorInput other = (AlignmentEditorInput) obj;
		if (sequenceNodeUuid == null) {
			if (other.sequenceNodeUuid != null) {
                return false;
            }
		} else if (!sequenceNodeUuid.equals(other.sequenceNodeUuid)) {
            return false;
        }
		return true;
	}


	public void setSequenceNode(Sequence sequenceNode) {
	    this.sequenceNode = sequenceNode;
	}

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.session.ICdmEntitySessionEnabled#getRootEntities()
     */
    @Override
    public List<Sequence> getRootEntities() {
        return Arrays.asList(sequenceNode);
    }


    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.editor.CdmEntitySessionInput#merge()
     */
    @Override
    public void merge() {
        if(CdmStore.getCurrentSessionManager().isRemoting()) {
            CdmStore.getService(ISequenceService.class).merge(sequenceNode, true);
        }
    }
}
